#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2008 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Text;

namespace HeuristicLab.PluginInfrastructure {
  /// <summary>
  /// This attribute can be used to specify meta data for applications. 
  /// For example to specify name, version and description of applications.
  /// </summary>
  [AttributeUsage(AttributeTargets.Class)]
  public class ApplicationAttribute : System.Attribute {
    private string name;
    /// <summary>
    /// Gets or sets the name of the application.
    /// </summary>
    public string Name {
      get { return name; }
      set { name = value; }
    }

    //private string version;
    ///// <summary>
    ///// Gets or sets the version of the application.
    ///// </summary>
    //public string Version {
    //  get { return version; }
    //  set { version = value; }
    //}

    private string description;
    /// <summary>
    /// Gets or sets the description of the application.
    /// </summary>
    public string Description {
      get { return description; }
      set { description = value; }
    }

    private bool restartOnErrors;
    /// <summary>
    /// Gets or sets the boolean flag whether the plugin should be automatically restarted when it is closed because of an exception (for services).
    /// </summary>
    public bool RestartOnErrors {
      get { return restartOnErrors; }
      set { restartOnErrors = value; }
    }

    /// <summary>
    /// Initializes a new instance of <see cref="ApplicationAttribute"/>.
    /// <param name="name">Name of the application</param>
    /// </summary>
    public ApplicationAttribute(string name)
      : this(name, "") {
    }

    /// <summary>
    /// Initializes a new instance of <see cref="ApplicationAttribute"/>.
    /// <param name="name">Name of the application</param>
    /// <param name="description">Description of the application</param>
    /// </summary>
    public ApplicationAttribute(string name, string description)
      : this(name, description, false) {
    }

    ///// <summary>
    ///// Initializes a new instance of <see cref="ApplicationAttribute"/>.
    ///// <param name="name">Name of the application</param>
    ///// <param name="description">Description of the application</param>
    ///// <param name="version">Version string of the application</param>
    ///// </summary>
    //public ApplicationAttribute(string name, string description, string version)
    //  : this(name, description, version, false) {
    //}

    /// <summary>
    /// Initializes a new instance of <see cref="ApplicationAttribute"/>.
    /// <param name="name">Name of the application</param>
    /// <param name="description">Description of the application</param>
    /// <param name="version">Version string of the application</param>
    /// <param name="restartOnErrors">Flag that indicates if the application should be restarted on exceptions (for services)</param>
    /// </summary>
    public ApplicationAttribute(string name, string description, bool restartOnErrors) {
      this.name = name;
      this.description = description;
      this.restartOnErrors = restartOnErrors;
    }
  }
}
